@@ -11,22 +11,13 @@ use super::{
     RegisterDescription, ValueCtxt,
 };
 
+#[derive(Default)]
 pub struct GenApiBuilder<T = DefaultNodeStore, U = DefaultValueStore, S = DefaultCacheStore> {
     node_store: T,
     value_store: U,
     cache_store: S,
 }
 
-impl Default for GenApiBuilder {
-    fn default() -> Self {
-        Self {
-            node_store: DefaultNodeStore::default(),
-            value_store: DefaultValueStore::default(),
-            cache_store: DefaultCacheStore::default(),
-        }
-    }
-}
-
 pub type BuildResult<T, U, S> = parser::ParseResult<(RegisterDescription, T, ValueCtxt<U, S>)>;
 
 impl<T, U, S> GenApiBuilder<T, U, S> {
@@ -96,6 +87,9 @@ pub trait NodeStoreBuilder {
     fn get_or_intern<T>(&mut self, node_name: T) -> NodeId
     where
         T: AsRef<str>;
+
+    /// Returns fresh id for each call.
+    fn fresh_id(&mut self) -> u32;
 }
 
 pub trait ValueStoreBuilder {
