@@ -46,7 +46,6 @@ pub(super) const POLLING_TIME: &str = "PollingTime";
 pub(super) const ON_VALUE: &str = "OnValue";
 pub(super) const OFF_VALUE: &str = "OffValue";
 pub(super) const NUMERIC_VALUE: &str = "NumericValue";
-pub(super) const SYMBOLIC: &str = "Symbolic";
 pub(super) const IS_SELF_CLEARING: &str = "IsSelfClearing";
 pub(super) const MIN: &str = "Min";
 pub(super) const P_MIN: &str = "pMin";
@@ -76,7 +75,6 @@ pub(super) const INDEX: &str = "Index";
 pub(super) const P_INDEX: &str = "pIndex";
 pub(super) const ACCESS_MODE: &str = "AccessMode";
 pub(super) const CACHEABLE: &str = "Cachable"; // Schema typos "Cacheable" to "Cachable"
-pub(super) const COMMENT: &str = "Comment";
 pub(super) const VALUE: &str = "Value";
 pub(super) const P_VALUE: &str = "pValue";
 pub(super) const P_VALUE_COPY: &str = "pValueCopy";
